==> tdm_2.0.0.tar.gz: tdm/R/all.Amianhcrss.R <==
all.Amianhcrss<-function(){
     cat("\n")   
     cat("--------------------------------------------------------------\n")
     cat("    --Aminophylline anhydrous CR input data information--     \n")
     note_for_Thecrss_input()
     cat("--------------------------------------------------------------\n")                                                                   
     cat("\n")
     note_for_close_window()
     AmianhcrSSpar<-data.frame(parameter=c("Gender","age (yr)","ht (cm)","CHF","smoke","D (mg)","tau (hr)","c (mg/L)"),value=c(0))                                            
     AmianhcrSSpar<-edit(AmianhcrSSpar)                                                                                                                                           
     AmianhcrSSpar<-ycheck(AmianhcrSSpar)       
     cat("\n")                                                                                                                         
     Amianhcr.ss(AmianhcrSSpar[8,2],AmianhcrSSpar[7,2],AmianhcrSSpar[6,2],AmianhcrSSpar[3,2],AmianhcrSSpar[2,2],AmianhcrSSpar[5,2],AmianhcrSSpar[1,2],AmianhcrSSpar[4,2])
     note_for_convergence_plots()
     convergence_plots_sep()
     cat("-------------------------------------------------------------\n")
     cat("   --Aminophylline anhydrous CR output data information--    \n")
     note_for_Thecr_output()
     cat("-------------------------------------------------------------\n")
     show(samplesStats("*"))
     cat("\n") 
     C<-TheCRcpr(0.85,AmianhcrSSpar[6,2],AmianhcrSSpar[7,2])
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Css_pr (mg/L)")    
     show(coutput) 
     cat("\n")   
     Amianhcr.more()                            
}

==> tdm_2.2.3.tar.gz: tdm/R/all.Amianhcrss.R <==
all.Amianhcrss<-function(){
     cat("\n")   
     cat("--------------------------------------------------------------\n")
     cat("    --Aminophylline anhydrous CR input data information--     \n")
     note_for_Thecrss_input()
     cat("--------------------------------------------------------------\n")                                                                   
     cat("\n")
     note_for_close_window()
     AmianhcrSSpar<-data.frame(parameter=c("Gender","age (yr)","ht (cm)","CHF","smoke","D (mg)","tau (hr)","c (mg/L)"),value=c(0))                                            
     AmianhcrSSpar<-edit(AmianhcrSSpar)                                                                                                                                           
##     AmianhcrSSpar<-ycheck(AmianhcrSSpar)       
     cat("\n")                                                                                                                         
     Amianhcr.ss(AmianhcrSSpar[8,2],AmianhcrSSpar[7,2],AmianhcrSSpar[6,2],AmianhcrSSpar[3,2],AmianhcrSSpar[2,2],AmianhcrSSpar[5,2],AmianhcrSSpar[1,2],AmianhcrSSpar[4,2])
     note_for_convergence_plots()
     convergence_plots_sep()
     cat("-------------------------------------------------------------\n")
     cat("   --Aminophylline anhydrous CR output data information--    \n")
     note_for_Thecr_output()
     cat("-------------------------------------------------------------\n")
     show(samplesStats("*"))
     cat("\n") 
     C<-TheCRcpr(0.85,AmianhcrSSpar[6,2],AmianhcrSSpar[7,2])
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Css_pr (mg/L)")    
     show(coutput) 
     cat("\n")   
     Amianhcr.more()                            
}
